==> tuia-ecb-center-api-1.0.0.0-20190409.032612-25-sources.jar: cn/com/duiba/tuia/ecb/center/cpd/dto/CPDListDetailDto.java <==
package cn.com.duiba.tuia.ecb.center.cpd.dto;

import cn.com.duiba.tuia.ecb.center.cpd.enums.AppSourceEnum;
import com.google.common.collect.Maps;

import java.io.Serializable;
import java.util.Date;
import java.util.Map;

/**
 * 应用试玩列表dto
 * @author lichao 2019/4/4
 */
public class CPDListDetailDto implements Serializable {

    //应用id，第三方的广告id
    private String id;

    //当前的任务状态 0初始化 1已下载过
    private int missionStatus;

    /**
     * 应用来源,
     * @see AppSourceEnum
     */
    private Integer appSource;

    //应用名称
    private String appName;

    //应用描述
    private String appDesc;

    //应用图标
    private String appLogo;

    //下载地址
    private String appUrl;

    //包名
    private String appPackage;

    //应用大小
    private String appSize;

    //奖励提示:需要时使用
    private String rewardTips;

    //app最短体验时长 单位秒
    private Integer rewardExpTime;

    //今天的奖励
    private Integer reward;

    //奖励分布,备用,当业务需要时使用
    private String rewardSet;

    //下载完成的时间
    private Date gmtCreate;

    //扩展字段
    private String extInfo;

    private EmbedUrlDto embedUrls;


    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public Integer getAppSource() {
        return appSource;
    }

    public void setAppSource(Integer appSource) {
        this.appSource = appSource;
    }

    public String getAppName() {
        return appName;
    }

    public void setAppName(String appName) {
        this.appName = appName;
    }

    public String getAppDesc() {
        return appDesc;
    }

    public void setAppDesc(String appDesc) {
        this.appDesc = appDesc;
    }

    public String getAppLogo() {
        return appLogo;
    }

    public void setAppLogo(String appLogo) {
        this.appLogo = appLogo;
    }

    public String getAppUrl() {
        return appUrl;
    }

    public void setAppUrl(String appUrl) {
        this.appUrl = appUrl;
    }

    public String getAppPackage() {
        return appPackage;
    }

    public void setAppPackage(String appPackage) {
        this.appPackage = appPackage;
    }

    public String getAppSize() {
        return appSize;
    }

    public void setAppSize(String appSize) {
        this.appSize = appSize;
    }

    public String getRewardTips() {
        return rewardTips;
    }

    public void setRewardTips(String rewardTips) {
        this.rewardTips = rewardTips;
    }

    public Integer getRewardExpTime() {
        return rewardExpTime;
    }

    public void setRewardExpTime(Integer rewardExpTime) {
        this.rewardExpTime = rewardExpTime;
    }

    public Integer getReward() {
        return reward;
    }

    public void setReward(Integer reward) {
        this.reward = reward;
    }

    public String getRewardSet() {
        return rewardSet;
    }

    public void setRewardSet(String rewardSet) {
        this.rewardSet = rewardSet;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public String getExtInfo() {
        return extInfo;
    }

    public void setExtInfo(String extInfo) {
        this.extInfo = extInfo;
    }



    public int getMissionStatus() {
        return missionStatus;
    }

    public void setMissionStatus(int missionStatus) {
        this.missionStatus = missionStatus;
    }

    public EmbedUrlDto getEmbedUrls() {
        return embedUrls;
    }

    public void setEmbedUrls(EmbedUrlDto embedUrls) {
        this.embedUrls = embedUrls;
    }
}

==> tuia-ecb-center-api-1.0.0.0-20190411.101220-43-sources.jar: cn/com/duiba/tuia/ecb/center/cpd/dto/CPDListDetailDto.java <==
package cn.com.duiba.tuia.ecb.center.cpd.dto;

import cn.com.duiba.tuia.ecb.center.cpd.enums.AppSourceEnum;
import com.google.common.collect.Maps;

import java.io.Serializable;
import java.util.Date;
import java.util.Map;

/**
 * 应用试玩列表dto
 * @author lichao 2019/4/4
 */
public class CPDListDetailDto implements Serializable {

    //应用id，第三方的广告id
    private String id;

    //当前的任务状态 0初始化 1已下载过 2可领取
    private int missionStatus;

    /**
     * 应用来源,
     * @see AppSourceEnum
     */
    private Integer appSource;

    //应用名称
    private String appName;

    //应用描述
    private String appDesc;

    //应用图标
    private String appLogo;

    //下载地址
    private String appUrl;

    //包名
    private String appPackage;

    //应用大小
    private String appSize;

    //奖励提示:需要时使用
    private String rewardTips;

    //app最短体验时长 单位秒
    private Integer rewardExpTime;

    //今天的奖励
    private Integer reward;

    //奖励分布,备用,当业务需要时使用
    private String rewardSet;

    //下载完成的时间
    private Date gmtCreate;

    //扩展字段
    private String extInfo;

    private EmbedUrlDto embedUrls;


    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public Integer getAppSource() {
        return appSource;
    }

    public void setAppSource(Integer appSource) {
        this.appSource = appSource;
    }

    public String getAppName() {
        return appName;
    }

    public void setAppName(String appName) {
        this.appName = appName;
    }

    public String getAppDesc() {
        return appDesc;
    }

    public void setAppDesc(String appDesc) {
        this.appDesc = appDesc;
    }

    public String getAppLogo() {
        return appLogo;
    }

    public void setAppLogo(String appLogo) {
        this.appLogo = appLogo;
    }

    public String getAppUrl() {
        return appUrl;
    }

    public void setAppUrl(String appUrl) {
        this.appUrl = appUrl;
    }

    public String getAppPackage() {
        return appPackage;
    }

    public void setAppPackage(String appPackage) {
        this.appPackage = appPackage;
    }

    public String getAppSize() {
        return appSize;
    }

    public void setAppSize(String appSize) {
        this.appSize = appSize;
    }

    public String getRewardTips() {
        return rewardTips;
    }

    public void setRewardTips(String rewardTips) {
        this.rewardTips = rewardTips;
    }

    public Integer getRewardExpTime() {
        return rewardExpTime;
    }

    public void setRewardExpTime(Integer rewardExpTime) {
        this.rewardExpTime = rewardExpTime;
    }

    public Integer getReward() {
        return reward;
    }

    public void setReward(Integer reward) {
        this.reward = reward;
    }

    public String getRewardSet() {
        return rewardSet;
    }

    public void setRewardSet(String rewardSet) {
        this.rewardSet = rewardSet;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public String getExtInfo() {
        return extInfo;
    }

    public void setExtInfo(String extInfo) {
        this.extInfo = extInfo;
    }



    public int getMissionStatus() {
        return missionStatus;
    }

    public void setMissionStatus(int missionStatus) {
        this.missionStatus = missionStatus;
    }

    public EmbedUrlDto getEmbedUrls() {
        return embedUrls;
    }

    public void setEmbedUrls(EmbedUrlDto embedUrls) {
        this.embedUrls = embedUrls;
    }
}
